@@ -5,10 +5,10 @@ import signal
 import socket
 import weakref
 from collections.abc import Iterable, Sequence
-from contextlib import contextmanager
+from contextlib import contextmanager, suppress
 from enum import auto
 from functools import partial
-from typing import TYPE_CHECKING
+from typing import TYPE_CHECKING, Literal
 
 import numpy as np
 import qtpy
@@ -104,7 +104,9 @@ def str_to_qbytearray(string: str) -> QByteArray:
     return QByteArray.fromBase64(string[len(QBYTE_FLAG) :].encode())
 
 
-def QImg2array(img) -> np.ndarray:
+def QImg2array(
+    img,
+) -> np.ndarray[tuple[int, int, Literal[4]], np.dtype[np.uint8]]:
     """Convert QImage to an array.
 
     Parameters
@@ -321,13 +323,10 @@ def remove_flash_animation(widget_ref: weakref.ref[QWidget]):
     if widget_ref() is None:
         return
     widget = widget_ref()
-    try:
+    with suppress(RuntimeError):
         widget.setGraphicsEffect(None)
         widget._flash_animation.deleteLater()
         del widget._flash_animation
-    except RuntimeError:
-        # RuntimeError: wrapped C/C++ object of type QtWidgetOverlay deleted
-        pass
 
 
 @contextmanager
@@ -423,7 +422,7 @@ def in_qt_main_thread() -> bool:
 
 def get_color(
     color: str | np.ndarray | QColor | None = None,
-    mode: ColorMode = ColorMode.HEX,
+    mode: ColorMode | Literal['hex', 'qcolor', 'array'] = ColorMode.HEX,
 ) -> np.ndarray | None:
     """
     Helper function to get a color from q QColorDialog.
@@ -460,3 +459,7 @@ def get_color(
                 / 255
             )
     return new_color
+
+
+def checked_to_bool(value: Qt.CheckState) -> bool:
+    return Qt.CheckState(value) == Qt.CheckState.Checked
