@@ -390,6 +390,24 @@ def test_adding_points():
     np.testing.assert_equal(layer.data, np.vstack((data, coord)))
 
 
+def test_adding_points_symbol():
+    """Test that the current symbol is used for added point."""
+    # add a point with default (disc) symbol
+    shape = (1, 2)
+    np.random.seed(0)
+    data = 20 * np.random.random(shape)
+    layer = Points(data)
+
+    # update the current symbol
+    new_symbol = 'star'
+    layer.current_symbol = new_symbol
+    coord = [20, 20]
+    layer.add(coord)
+
+    # confirm that a newly created point has the updated symbol
+    assert layer.symbol[-1] == new_symbol
+
+
 def test_points_selection_with_setter():
     shape = (10, 2)
     np.random.seed(0)
@@ -416,8 +434,30 @@ def test_adding_points_to_empty():
     assert layer.selected_data == {0}
 
 
+def test_removing_points():
+    """Test removing points, including with selection."""
+    shape = (10, 2)
+    np.random.seed(0)
+    data = 20 * np.random.random(shape)
+    layer = Points(data)
+    # select some points
+    layer.selected_data = {1, 2, 4, 6}
+
+    # Remove points by index
+    layer.remove([0, 2, 5])
+    assert len(layer.data) == shape[0] - 3
+    assert np.array_equal(layer.data, data[[1, 3, 4, 6, 7, 8, 9]])
+
+    # check selection after removal
+    # one selected point was removed, the other indexes need to be shifted
+    assert layer.selected_data == {0, 2, 3}
+
+    # removing nothing should work smoothly
+    layer.remove([])
+
+
 def test_removing_selected_points():
-    """Test selecting points."""
+    """Test removing selected points."""
     shape = (10, 2)
     np.random.seed(0)
     data = 20 * np.random.random(shape)
@@ -442,6 +482,26 @@ def test_removing_selected_points():
     assert len(layer.data) == shape[0] - 3
 
 
+def test_popping_points():
+    """Test popping points."""
+    shape = (10, 2)
+    np.random.seed(0)
+    data = 20 * np.random.random(shape)
+    layer = Points(data)
+
+    # Pop point by default index
+    popped = layer.pop()
+    assert len(layer.data) == shape[0] - 1
+    assert np.array_equal(popped['data'], data[-1])
+    assert np.array_equal(layer.data, data[:-1])
+
+    # Pop a point by index at 3
+    popped = layer.pop(3)
+    assert len(layer.data) == shape[0] - 2
+    assert np.array_equal(popped['data'], data[3])
+    assert np.array_equal(layer.data, data[[0, 1, 2, 4, 5, 6, 7, 8]])
+
+
 def test_deleting_selected_value_changes():
     """Test deleting selected points appropriately sets self._value"""
     shape = (10, 2)
@@ -1020,6 +1080,24 @@ def test_border_width():
         layer.border_width = -2
 
 
+def test_border_width_update():
+    """Test that the current border width is updated."""
+    # add a point with default border width
+    shape = (1, 2)
+    np.random.seed(0)
+    data = 20 * np.random.random(shape)
+    layer = Points(data)
+
+    # update the current border width to an arbitrary value
+    new_border_width = 0.43
+    layer.current_border_width = new_border_width
+    coord = [20, 20]
+    layer.add(coord)
+
+    # confirm that a newly created point has the updated border width
+    assert layer.border_width[-1] == new_border_width
+
+
 @pytest.mark.parametrize(
     'border_width',
     [1, float(1), np.array([1, 2, 3, 4, 5]), [1, 2, 3, 4, 5]],
@@ -2702,3 +2780,15 @@ def test_docstring():
     validate_all_params_in_docstring(Points)
     validate_kwargs_sorted(Points)
     validate_docstring_parent_class_consistency(Points)
+
+
+def test_points_layer_display_correct_slice_on_scale(viewer_model):
+    data = np.zeros((60, 60, 60))
+    viewer_model.add_image(data, scale=[0.29, 0.26, 0.26])
+    pts = viewer_model.add_points(name='test', size=1, ndim=3)
+    pts.add((8.7, 0, 0))
+    viewer_model.dims.set_point(0, 30 * 0.29)  # middle plane
+
+    request = pts._make_slice_request(viewer_model.dims)
+    response = request()
+    np.testing.assert_equal(response.indices, [0])
